@@ -560,7 +560,6 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
     @classmethod
     def _put(cls, path, url, content_type):
         size = os.path.getsize(path)
-
         with requests.Session() as session:
             headers = {'Content-Type': content_type}
 
@@ -632,7 +631,9 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
                         path = path.replace(os.path.sep, '/')
 
                         key = target_path
-                        if not source_path_is_file:
+                        if source_path_is_file:
+                            key += source_name
+                        else:
                             if not has_trailing_slash:
                                 key += source_name + '/'
                             key += path[len(source_path)+1:]
